* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Step 1: Add Data](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment-define-scope)
  * Add Applications
